@@ -65,31 +65,33 @@ static int _disk_raw_add (PedDisk* disk, PedPartition* part);
 static PedDiskType*	disk_types = NULL;
 
 void
-ped_register_disk_type (PedDiskType* type)
+ped_register_disk_type (PedDiskType* disk_type)
 {
-	PED_ASSERT (type != NULL, return);
-	PED_ASSERT (type->ops != NULL, return);
-	PED_ASSERT (type->name != NULL, return);
+	PED_ASSERT (disk_type != NULL, return);
+	PED_ASSERT (disk_type->ops != NULL, return);
+	PED_ASSERT (disk_type->name != NULL, return);
 	
-	((struct _PedDiskType*) type)->next = disk_types;
-	disk_types = (struct _PedDiskType*) type;
+	/* pretend that "next" isn't part of the struct :-) */
+	((struct _PedDiskType*) disk_type)->next = disk_types;
+	disk_types = (struct _PedDiskType*) disk_type;
 }
 
-void ped_unregister_disk_type (PedDiskType* type)
+void ped_unregister_disk_type (PedDiskType* disk_type)
 {
 	PedDiskType*	walk;
 	PedDiskType*	last = NULL;
 
-	PED_ASSERT (type != NULL, return);
+	PED_ASSERT (disk_types != NULL, return);
+	PED_ASSERT (disk_type != NULL, return);
 
-	for (walk = disk_types; walk != NULL; last = walk, walk = walk->next) {
-		if (walk == type) break;
-	}
+	for (walk = disk_types; walk && walk != disk_type;
+                last = walk, walk = walk->next);
 
+	PED_ASSERT (walk != NULL, return);
 	if (last)
-		((struct _PedDiskType*) last)->next = type->next;
+		((struct _PedDiskType*) last)->next = disk_type->next;
 	else
-		disk_types = type->next;
+		disk_types = disk_type->next;
 }
 
 /**
@@ -1261,8 +1263,8 @@ ped_partition_set_name (PedPartition* part, const char* name)
 }
 
 /**
- * Returns the name of a partition \p part.  This will only work if the disk label
- * supports it.
+ * Returns the name of a partition \p part.  This will only work if the disk
+ * label supports it.
  *
  * \note The returned string should not be modified.  It should
  *	not be referenced after the partition is destroyed.
@@ -1724,8 +1726,8 @@ _check_partition (PedDisk* disk, PedPartition* part)
  * Adds PedPartition \p part to PedPartition \p disk.
  * 
  * \warning The partition's geometry may be changed, subject to \p constraint.
- * You could set \p constraint to <tt>ped_constraint_exact(&part->geom)</tt>, but
- * many partition table schemes have special requirements on the start
+ * You could set \p constraint to <tt>ped_constraint_exact(&part->geom)</tt>,
+ * but many partition table schemes have special requirements on the start
  * and end of partitions.  Therefore, having an overly strict constraint
  * will probably mean that this function will fail (in which
  * case \p part will be left unmodified)
